pub struct AutomationRule {
pub advance_rollout_rule: Option<AdvanceRolloutRule>,
pub promote_release_rule: Option<PromoteReleaseRule>,
pub repair_rollout_rule: Option<RepairRolloutRule>,
pub timed_promote_release_rule: Option<TimedPromoteReleaseRule>,
}Expand description
AutomationRule defines the automation activities.
This type is not used in any activity, and only used as part of another schema.
Fields
advance_rollout_rule: Option<AdvanceRolloutRule>Optional. The AdvanceRolloutRule will automatically advance a successful Rollout.
promote_release_rule: Option<PromoteReleaseRule>Optional. PromoteReleaseRule will automatically promote a release from the current target to a specified target.
repair_rollout_rule: Option<RepairRolloutRule>Optional. The RepairRolloutRule will automatically repair a failed rollout.
timed_promote_release_rule: Option<TimedPromoteReleaseRule>Optional. The TimedPromoteReleaseRule will automatically promote a release from the current target(s) to the specified target(s) on a configured schedule.