pub struct AutomationRuleCondition {
pub targets_present_condition: Option<TargetsPresentCondition>,
pub timed_promote_release_condition: Option<TimedPromoteReleaseCondition>,
}Expand description
AutomationRuleCondition contains conditions relevant to an Automation rule.
This type is not used in any activity, and only used as part of another schema.
Fields
targets_present_condition: Option<TargetsPresentCondition>Optional. Details around targets enumerated in the rule.
timed_promote_release_condition: Option<TimedPromoteReleaseCondition>Optional. TimedPromoteReleaseCondition contains rule conditions specific to a an Automation with a timed promote release rule defined.