pub struct Config {
pub default_skaffold_version: Option<String>,
pub default_tool_versions: Option<ToolVersions>,
pub name: Option<String>,
pub supported_versions: Option<Vec<SkaffoldVersion>>,
}Expand description
Service-wide configuration.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations get config projects (response)
Fields
default_skaffold_version: Option<String>Default Skaffold version that is assigned when a Release is created without specifying a Skaffold version.
default_tool_versions: Option<ToolVersions>Output only. Default tool versions. These tool versions are assigned when a Release is created without specifying tool versions.
name: Option<String>Name of the configuration.
supported_versions: Option<Vec<SkaffoldVersion>>All supported versions of Skaffold.