pub struct DeliveryPipelineAttribute {
pub id: Option<String>,
pub labels: Option<HashMap<String, String>>,
}Expand description
Contains criteria for selecting DeliveryPipelines.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>Optional. ID of the DeliveryPipeline. The value of this field could be one of the following: * The last segment of a pipeline name * “*”, all delivery pipelines in a location
labels: Option<HashMap<String, String>>DeliveryPipeline labels.