DeployPolicyResourceSelector

Struct DeployPolicyResourceSelector 

pub struct DeployPolicyResourceSelector {
    pub delivery_pipeline: Option<DeliveryPipelineAttribute>,
    pub target: Option<TargetAttribute>,
}
Contains information on the resources to select for a deploy policy. Attributes provided must all match the resource in order for policy restrictions to apply. For example, if delivery pipelines attributes given are an id “prod” and labels “foo: bar”, a delivery pipeline resource must match both that id and have that label in order to be subject to the policy.

This type is not used in any activity, and only used as part of another schema.

Fields

delivery_pipeline: Option<DeliveryPipelineAttribute>

Optional. Contains attributes about a delivery pipeline.

target: Option<TargetAttribute>

Optional. Contains attributes about a target.