pub struct ExecutionConfig {
pub artifact_storage: Option<String>,
pub default_pool: Option<DefaultPool>,
pub execution_timeout: Option<Duration>,
pub private_pool: Option<PrivatePool>,
pub service_account: Option<String>,
pub usages: Option<Vec<String>>,
pub verbose: Option<bool>,
pub worker_pool: Option<String>,
}Expand description
Configuration of the environment to use when calling Skaffold.
This type is not used in any activity, and only used as part of another schema.
Fields
artifact_storage: Option<String>Optional. Cloud Storage location in which to store execution outputs. This can either be a bucket (“gs://my-bucket”) or a path within a bucket (“gs://my-bucket/my-dir”). If unspecified, a default bucket located in the same region will be used.
default_pool: Option<DefaultPool>Optional. Use default Cloud Build pool.
execution_timeout: Option<Duration>Optional. Execution timeout for a Cloud Build Execution. This must be between 10m and 24h in seconds format. If unspecified, a default timeout of 1h is used.
private_pool: Option<PrivatePool>Optional. Use private Cloud Build pool.
service_account: Option<String>Optional. Google service account to use for execution. If unspecified, the project execution service account (-compute@developer.gserviceaccount.com) is used.
usages: Option<Vec<String>>Required. Usages when this configuration should be applied.
verbose: Option<bool>Optional. If true, additional logging will be enabled when running builds in this execution environment.
worker_pool: Option<String>Optional. The resource name of the WorkerPool, with the format projects/{project}/locations/{location}/workerPools/{worker_pool}. If this optional field is unspecified, the default Cloud Build pool will be used.