GatewayServiceMesh

Struct GatewayServiceMesh 

pub struct GatewayServiceMesh {
    pub deployment: Option<String>,
    pub http_route: Option<String>,
    pub pod_selector_label: Option<String>,
    pub route_destinations: Option<RouteDestinations>,
    pub route_update_wait_time: Option<Duration>,
    pub service: Option<String>,
    pub stable_cutback_duration: Option<Duration>,
}
Information about the Kubernetes Gateway API service mesh configuration.

This type is not used in any activity, and only used as part of another schema.

Fields

deployment: Option<String>

Required. Name of the Kubernetes Deployment whose traffic is managed by the specified HTTPRoute and Service.

http_route: Option<String>

Required. Name of the Gateway API HTTPRoute.

pod_selector_label: Option<String>

Optional. The label to use when selecting Pods for the Deployment and Service resources. This label must already be present in both resources.

route_destinations: Option<RouteDestinations>

Optional. Route destinations allow configuring the Gateway API HTTPRoute to be deployed to additional clusters. This option is available for multi-cluster service mesh set ups that require the route to exist in the clusters that call the service. If unspecified, the HTTPRoute will only be deployed to the Target cluster.

route_update_wait_time: Option<Duration>

Optional. The time to wait for route updates to propagate. The maximum configurable time is 3 hours, in seconds format. If unspecified, there is no wait time.

service: Option<String>

Required. Name of the Kubernetes Service.

stable_cutback_duration: Option<Duration>

Optional. The amount of time to migrate traffic back from the canary Service to the original Service during the stable phase deployment. If specified, must be between 15s and 3600s. If unspecified, there is no cutback time.