PolicyViolation

Struct PolicyViolation 

pub struct PolicyViolation {
    pub policy_violation_details: Option<Vec<PolicyViolationDetails>>,
}
Returned from an action if one or more policies were violated, and therefore the action was prevented. Contains information about what policies were violated and why.

This type is not used in any activity, and only used as part of another schema.

Fields

policy_violation_details: Option<Vec<PolicyViolationDetails>>

Policy violation details.