pub struct ProjectMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on project resources.
It is not used directly, but through the CloudDeploy hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_clouddeploy1 as clouddeploy1;
use clouddeploy1::{CloudDeploy, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CloudDeploy::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `locations_custom_target_types_create(...)`, `locations_custom_target_types_delete(...)`, `locations_custom_target_types_get(...)`, `locations_custom_target_types_get_iam_policy(...)`, `locations_custom_target_types_list(...)`, `locations_custom_target_types_patch(...)`, `locations_custom_target_types_set_iam_policy(...)`, `locations_delivery_pipelines_automation_runs_cancel(...)`, `locations_delivery_pipelines_automation_runs_get(...)`, `locations_delivery_pipelines_automation_runs_list(...)`, `locations_delivery_pipelines_automations_create(...)`, `locations_delivery_pipelines_automations_delete(...)`, `locations_delivery_pipelines_automations_get(...)`, `locations_delivery_pipelines_automations_list(...)`, `locations_delivery_pipelines_automations_patch(...)`, `locations_delivery_pipelines_create(...)`, `locations_delivery_pipelines_delete(...)`, `locations_delivery_pipelines_get(...)`, `locations_delivery_pipelines_get_iam_policy(...)`, `locations_delivery_pipelines_list(...)`, `locations_delivery_pipelines_patch(...)`, `locations_delivery_pipelines_releases_abandon(...)`, `locations_delivery_pipelines_releases_create(...)`, `locations_delivery_pipelines_releases_get(...)`, `locations_delivery_pipelines_releases_list(...)`, `locations_delivery_pipelines_releases_rollouts_advance(...)`, `locations_delivery_pipelines_releases_rollouts_approve(...)`, `locations_delivery_pipelines_releases_rollouts_cancel(...)`, `locations_delivery_pipelines_releases_rollouts_create(...)`, `locations_delivery_pipelines_releases_rollouts_get(...)`, `locations_delivery_pipelines_releases_rollouts_ignore_job(...)`, `locations_delivery_pipelines_releases_rollouts_job_runs_get(...)`, `locations_delivery_pipelines_releases_rollouts_job_runs_list(...)`, `locations_delivery_pipelines_releases_rollouts_job_runs_terminate(...)`, `locations_delivery_pipelines_releases_rollouts_list(...)`, `locations_delivery_pipelines_releases_rollouts_retry_job(...)`, `locations_delivery_pipelines_rollback_target(...)`, `locations_delivery_pipelines_set_iam_policy(...)`, `locations_delivery_pipelines_test_iam_permissions(...)`, `locations_deploy_policies_create(...)`, `locations_deploy_policies_delete(...)`, `locations_deploy_policies_get(...)`, `locations_deploy_policies_get_iam_policy(...)`, `locations_deploy_policies_list(...)`, `locations_deploy_policies_patch(...)`, `locations_deploy_policies_set_iam_policy(...)`, `locations_get(...)`, `locations_get_config(...)`, `locations_list(...)`, `locations_operations_cancel(...)`, `locations_operations_delete(...)`, `locations_operations_get(...)`, `locations_operations_list(...)`, `locations_targets_create(...)`, `locations_targets_delete(...)`, `locations_targets_get(...)`, `locations_targets_get_iam_policy(...)`, `locations_targets_list(...)`, `locations_targets_patch(...)`, `locations_targets_set_iam_policy(...)` and `locations_targets_test_iam_permissions(...)`
// to build up your call.
let rb = hub.projects();Implementations
Sourceimpl<'a, C> ProjectMethods<'a, C>
impl<'a, C> ProjectMethods<'a, C>
Sourcepub fn locations_custom_target_types_create(
&self,
request: CustomTargetType,
parent: &str,
) -> ProjectLocationCustomTargetTypeCreateCall<'a, C>
pub fn locations_custom_target_types_create( &self, request: CustomTargetType, parent: &str, ) -> ProjectLocationCustomTargetTypeCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a new CustomTargetType in a given project and location.
Arguments
request- No description provided.parent- Required. The parent collection in which theCustomTargetTypemust be created. The format isprojects/{project_id}/locations/{location_name}.
Sourcepub fn locations_custom_target_types_delete(
&self,
name: &str,
) -> ProjectLocationCustomTargetTypeDeleteCall<'a, C>
pub fn locations_custom_target_types_delete( &self, name: &str, ) -> ProjectLocationCustomTargetTypeDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a single CustomTargetType.
Arguments
name- Required. The name of theCustomTargetTypeto delete. Format must beprojects/{project_id}/locations/{location_name}/customTargetTypes/{custom_target_type}.
Sourcepub fn locations_custom_target_types_get(
&self,
name: &str,
) -> ProjectLocationCustomTargetTypeGetCall<'a, C>
pub fn locations_custom_target_types_get( &self, name: &str, ) -> ProjectLocationCustomTargetTypeGetCall<'a, C>
Create a builder to help you perform the following task:
Gets details of a single CustomTargetType.
Arguments
name- Required. Name of theCustomTargetType. Format must beprojects/{project_id}/locations/{location_name}/customTargetTypes/{custom_target_type}.
Sourcepub fn locations_custom_target_types_get_iam_policy(
&self,
resource: &str,
) -> ProjectLocationCustomTargetTypeGetIamPolicyCall<'a, C>
pub fn locations_custom_target_types_get_iam_policy( &self, resource: &str, ) -> ProjectLocationCustomTargetTypeGetIamPolicyCall<'a, C>
Create a builder to help you perform the following task:
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Arguments
resource- REQUIRED: The resource for which the policy is being requested. See Resource names for the appropriate value for this field.
Sourcepub fn locations_custom_target_types_list(
&self,
parent: &str,
) -> ProjectLocationCustomTargetTypeListCall<'a, C>
pub fn locations_custom_target_types_list( &self, parent: &str, ) -> ProjectLocationCustomTargetTypeListCall<'a, C>
Create a builder to help you perform the following task:
Lists CustomTargetTypes in a given project and location.
Arguments
parent- Required. The parent that owns this collection of custom target types. Format must beprojects/{project_id}/locations/{location_name}.
Sourcepub fn locations_custom_target_types_patch(
&self,
request: CustomTargetType,
name: &str,
) -> ProjectLocationCustomTargetTypePatchCall<'a, C>
pub fn locations_custom_target_types_patch( &self, request: CustomTargetType, name: &str, ) -> ProjectLocationCustomTargetTypePatchCall<'a, C>
Create a builder to help you perform the following task:
Updates a single CustomTargetType.
Arguments
request- No description provided.name- Identifier. Name of theCustomTargetType. Format isprojects/{project}/locations/{location}/customTargetTypes/{customTargetType}. ThecustomTargetTypecomponent must match[a-z]([a-z0-9-]{0,61}[a-z0-9])?
Sourcepub fn locations_custom_target_types_set_iam_policy(
&self,
request: SetIamPolicyRequest,
resource: &str,
) -> ProjectLocationCustomTargetTypeSetIamPolicyCall<'a, C>
pub fn locations_custom_target_types_set_iam_policy( &self, request: SetIamPolicyRequest, resource: &str, ) -> ProjectLocationCustomTargetTypeSetIamPolicyCall<'a, C>
Create a builder to help you perform the following task:
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy is being specified. See Resource names for the appropriate value for this field.
Sourcepub fn locations_delivery_pipelines_automation_runs_cancel(
&self,
request: CancelAutomationRunRequest,
name: &str,
) -> ProjectLocationDeliveryPipelineAutomationRunCancelCall<'a, C>
pub fn locations_delivery_pipelines_automation_runs_cancel( &self, request: CancelAutomationRunRequest, name: &str, ) -> ProjectLocationDeliveryPipelineAutomationRunCancelCall<'a, C>
Create a builder to help you perform the following task:
Cancels an AutomationRun. The state of the AutomationRun after cancelling is CANCELLED. CancelAutomationRun can be called on AutomationRun in the state IN_PROGRESS and PENDING; AutomationRun in a different state returns an FAILED_PRECONDITION error.
Arguments
request- No description provided.name- Required. Name of theAutomationRun. Format isprojects/{project}/locations/{location}/deliveryPipelines/{delivery_pipeline}/automationRuns/{automation_run}.
Sourcepub fn locations_delivery_pipelines_automation_runs_get(
&self,
name: &str,
) -> ProjectLocationDeliveryPipelineAutomationRunGetCall<'a, C>
pub fn locations_delivery_pipelines_automation_runs_get( &self, name: &str, ) -> ProjectLocationDeliveryPipelineAutomationRunGetCall<'a, C>
Create a builder to help you perform the following task:
Gets details of a single AutomationRun.
Arguments
name- Required. Name of theAutomationRun. Format must beprojects/{project}/locations/{location}/deliveryPipelines/{delivery_pipeline}/automationRuns/{automation_run}.
Sourcepub fn locations_delivery_pipelines_automation_runs_list(
&self,
parent: &str,
) -> ProjectLocationDeliveryPipelineAutomationRunListCall<'a, C>
pub fn locations_delivery_pipelines_automation_runs_list( &self, parent: &str, ) -> ProjectLocationDeliveryPipelineAutomationRunListCall<'a, C>
Create a builder to help you perform the following task:
Lists AutomationRuns in a given project and location.
Arguments
parent- Required. The parentDelivery Pipeline, which owns this collection of automationRuns. Format must beprojects/{project}/locations/{location}/deliveryPipelines/{delivery_pipeline}.
Sourcepub fn locations_delivery_pipelines_automations_create(
&self,
request: Automation,
parent: &str,
) -> ProjectLocationDeliveryPipelineAutomationCreateCall<'a, C>
pub fn locations_delivery_pipelines_automations_create( &self, request: Automation, parent: &str, ) -> ProjectLocationDeliveryPipelineAutomationCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a new Automation in a given project and location.
Arguments
request- No description provided.parent- Required. The parent collection in which theAutomationmust be created. The format isprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}.
Sourcepub fn locations_delivery_pipelines_automations_delete(
&self,
name: &str,
) -> ProjectLocationDeliveryPipelineAutomationDeleteCall<'a, C>
pub fn locations_delivery_pipelines_automations_delete( &self, name: &str, ) -> ProjectLocationDeliveryPipelineAutomationDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a single Automation resource.
Arguments
name- Required. The name of theAutomationto delete. The format isprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}/automations/{automation_name}.
Sourcepub fn locations_delivery_pipelines_automations_get(
&self,
name: &str,
) -> ProjectLocationDeliveryPipelineAutomationGetCall<'a, C>
pub fn locations_delivery_pipelines_automations_get( &self, name: &str, ) -> ProjectLocationDeliveryPipelineAutomationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets details of a single Automation.
Arguments
name- Required. Name of theAutomation. Format must beprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}/automations/{automation_name}.
Sourcepub fn locations_delivery_pipelines_automations_list(
&self,
parent: &str,
) -> ProjectLocationDeliveryPipelineAutomationListCall<'a, C>
pub fn locations_delivery_pipelines_automations_list( &self, parent: &str, ) -> ProjectLocationDeliveryPipelineAutomationListCall<'a, C>
Create a builder to help you perform the following task:
Lists Automations in a given project and location.
Arguments
parent- Required. The parentDelivery Pipeline, which owns this collection of automations. Format must beprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}.
Sourcepub fn locations_delivery_pipelines_automations_patch(
&self,
request: Automation,
name: &str,
) -> ProjectLocationDeliveryPipelineAutomationPatchCall<'a, C>
pub fn locations_delivery_pipelines_automations_patch( &self, request: Automation, name: &str, ) -> ProjectLocationDeliveryPipelineAutomationPatchCall<'a, C>
Create a builder to help you perform the following task:
Updates the parameters of a single Automation resource.
Arguments
request- No description provided.name- Output only. Name of theAutomation. Format isprojects/{project}/locations/{location}/deliveryPipelines/{delivery_pipeline}/automations/{automation}.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_job_runs_get(
&self,
name: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutJobRunGetCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_job_runs_get( &self, name: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutJobRunGetCall<'a, C>
Create a builder to help you perform the following task:
Gets details of a single JobRun.
Arguments
name- Required. Name of theJobRun. Format must beprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}/releases/{release_name}/rollouts/{rollout_name}/jobRuns/{job_run_name}.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_job_runs_list(
&self,
parent: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutJobRunListCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_job_runs_list( &self, parent: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutJobRunListCall<'a, C>
Create a builder to help you perform the following task:
Lists JobRuns in a given project and location.
Arguments
parent- Required. TheRolloutwhich owns this collection ofJobRunobjects.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_job_runs_terminate(
&self,
request: TerminateJobRunRequest,
name: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutJobRunTerminateCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_job_runs_terminate( &self, request: TerminateJobRunRequest, name: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutJobRunTerminateCall<'a, C>
Create a builder to help you perform the following task:
Terminates a Job Run in a given project and location.
Arguments
request- No description provided.name- Required. Name of theJobRun. Format must beprojects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}/releases/{release}/rollouts/{rollout}/jobRuns/{jobRun}.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_advance(
&self,
request: AdvanceRolloutRequest,
name: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutAdvanceCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_advance( &self, request: AdvanceRolloutRequest, name: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutAdvanceCall<'a, C>
Create a builder to help you perform the following task:
Advances a Rollout in a given project and location.
Arguments
request- No description provided.name- Required. Name of the Rollout. Format isprojects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}/releases/{release}/rollouts/{rollout}.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_approve(
&self,
request: ApproveRolloutRequest,
name: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutApproveCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_approve( &self, request: ApproveRolloutRequest, name: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutApproveCall<'a, C>
Create a builder to help you perform the following task:
Approves a Rollout.
Arguments
request- No description provided.name- Required. Name of the Rollout. Format isprojects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}/releases/{release}/rollouts/{rollout}.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_cancel(
&self,
request: CancelRolloutRequest,
name: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutCancelCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_cancel( &self, request: CancelRolloutRequest, name: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutCancelCall<'a, C>
Create a builder to help you perform the following task:
Cancels a Rollout in a given project and location.
Arguments
request- No description provided.name- Required. Name of the Rollout. Format isprojects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}/releases/{release}/rollouts/{rollout}.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_create(
&self,
request: Rollout,
parent: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutCreateCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_create( &self, request: Rollout, parent: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a new Rollout in a given project and location.
Arguments
request- No description provided.parent- Required. The parent collection in which theRolloutmust be created. The format isprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}/releases/{release_name}.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_get(
&self,
name: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutGetCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_get( &self, name: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutGetCall<'a, C>
Create a builder to help you perform the following task:
Gets details of a single Rollout.
Arguments
name- Required. Name of theRollout. Format must beprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}/releases/{release_name}/rollouts/{rollout_name}.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_ignore_job(
&self,
request: IgnoreJobRequest,
rollout: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutIgnoreJobCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_ignore_job( &self, request: IgnoreJobRequest, rollout: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutIgnoreJobCall<'a, C>
Create a builder to help you perform the following task:
Ignores the specified Job in a Rollout.
Arguments
request- No description provided.rollout- Required. Name of the Rollout. Format isprojects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}/releases/{release}/rollouts/{rollout}.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_list(
&self,
parent: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutListCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_list( &self, parent: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutListCall<'a, C>
Create a builder to help you perform the following task:
Lists Rollouts in a given project and location.
Arguments
parent- Required. TheReleasewhich owns this collection ofRolloutobjects.
Sourcepub fn locations_delivery_pipelines_releases_rollouts_retry_job(
&self,
request: RetryJobRequest,
rollout: &str,
) -> ProjectLocationDeliveryPipelineReleaseRolloutRetryJobCall<'a, C>
pub fn locations_delivery_pipelines_releases_rollouts_retry_job( &self, request: RetryJobRequest, rollout: &str, ) -> ProjectLocationDeliveryPipelineReleaseRolloutRetryJobCall<'a, C>
Create a builder to help you perform the following task:
Retries the specified Job in a Rollout.
Arguments
request- No description provided.rollout- Required. Name of the Rollout. Format isprojects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}/releases/{release}/rollouts/{rollout}.
Sourcepub fn locations_delivery_pipelines_releases_abandon(
&self,
request: AbandonReleaseRequest,
name: &str,
) -> ProjectLocationDeliveryPipelineReleaseAbandonCall<'a, C>
pub fn locations_delivery_pipelines_releases_abandon( &self, request: AbandonReleaseRequest, name: &str, ) -> ProjectLocationDeliveryPipelineReleaseAbandonCall<'a, C>
Create a builder to help you perform the following task:
Abandons a Release in the Delivery Pipeline.
Arguments
request- No description provided.name- Required. Name of the Release. Format isprojects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}/releases/{release}.
Sourcepub fn locations_delivery_pipelines_releases_create(
&self,
request: Release,
parent: &str,
) -> ProjectLocationDeliveryPipelineReleaseCreateCall<'a, C>
pub fn locations_delivery_pipelines_releases_create( &self, request: Release, parent: &str, ) -> ProjectLocationDeliveryPipelineReleaseCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a new Release in a given project and location.
Arguments
request- No description provided.parent- Required. The parent collection in which theReleaseis created. The format isprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}.
Sourcepub fn locations_delivery_pipelines_releases_get(
&self,
name: &str,
) -> ProjectLocationDeliveryPipelineReleaseGetCall<'a, C>
pub fn locations_delivery_pipelines_releases_get( &self, name: &str, ) -> ProjectLocationDeliveryPipelineReleaseGetCall<'a, C>
Create a builder to help you perform the following task:
Gets details of a single Release.
Arguments
name- Required. Name of theRelease. Format must beprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}/releases/{release_name}.
Sourcepub fn locations_delivery_pipelines_releases_list(
&self,
parent: &str,
) -> ProjectLocationDeliveryPipelineReleaseListCall<'a, C>
pub fn locations_delivery_pipelines_releases_list( &self, parent: &str, ) -> ProjectLocationDeliveryPipelineReleaseListCall<'a, C>
Create a builder to help you perform the following task:
Lists Releases in a given project and location.
Arguments
parent- Required. TheDeliveryPipelinewhich owns this collection ofReleaseobjects.
Sourcepub fn locations_delivery_pipelines_create(
&self,
request: DeliveryPipeline,
parent: &str,
) -> ProjectLocationDeliveryPipelineCreateCall<'a, C>
pub fn locations_delivery_pipelines_create( &self, request: DeliveryPipeline, parent: &str, ) -> ProjectLocationDeliveryPipelineCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a new DeliveryPipeline in a given project and location.
Arguments
request- No description provided.parent- Required. The parent collection in which theDeliveryPipelinemust be created. The format isprojects/{project_id}/locations/{location_name}.
Sourcepub fn locations_delivery_pipelines_delete(
&self,
name: &str,
) -> ProjectLocationDeliveryPipelineDeleteCall<'a, C>
pub fn locations_delivery_pipelines_delete( &self, name: &str, ) -> ProjectLocationDeliveryPipelineDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a single DeliveryPipeline.
Arguments
name- Required. The name of theDeliveryPipelineto delete. The format isprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}.
Sourcepub fn locations_delivery_pipelines_get(
&self,
name: &str,
) -> ProjectLocationDeliveryPipelineGetCall<'a, C>
pub fn locations_delivery_pipelines_get( &self, name: &str, ) -> ProjectLocationDeliveryPipelineGetCall<'a, C>
Create a builder to help you perform the following task:
Gets details of a single DeliveryPipeline.
Arguments
name- Required. Name of theDeliveryPipeline. Format must beprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}.
Sourcepub fn locations_delivery_pipelines_get_iam_policy(
&self,
resource: &str,
) -> ProjectLocationDeliveryPipelineGetIamPolicyCall<'a, C>
pub fn locations_delivery_pipelines_get_iam_policy( &self, resource: &str, ) -> ProjectLocationDeliveryPipelineGetIamPolicyCall<'a, C>
Create a builder to help you perform the following task:
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Arguments
resource- REQUIRED: The resource for which the policy is being requested. See Resource names for the appropriate value for this field.
Sourcepub fn locations_delivery_pipelines_list(
&self,
parent: &str,
) -> ProjectLocationDeliveryPipelineListCall<'a, C>
pub fn locations_delivery_pipelines_list( &self, parent: &str, ) -> ProjectLocationDeliveryPipelineListCall<'a, C>
Create a builder to help you perform the following task:
Lists DeliveryPipelines in a given project and location.
Arguments
parent- Required. The parent, which owns this collection of pipelines. Format must beprojects/{project_id}/locations/{location_name}.
Sourcepub fn locations_delivery_pipelines_patch(
&self,
request: DeliveryPipeline,
name: &str,
) -> ProjectLocationDeliveryPipelinePatchCall<'a, C>
pub fn locations_delivery_pipelines_patch( &self, request: DeliveryPipeline, name: &str, ) -> ProjectLocationDeliveryPipelinePatchCall<'a, C>
Create a builder to help you perform the following task:
Updates the parameters of a single DeliveryPipeline.
Arguments
request- No description provided.name- Identifier. Name of theDeliveryPipeline. Format isprojects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}. ThedeliveryPipelinecomponent must match[a-z]([a-z0-9-]{0,61}[a-z0-9])?
Sourcepub fn locations_delivery_pipelines_rollback_target(
&self,
request: RollbackTargetRequest,
name: &str,
) -> ProjectLocationDeliveryPipelineRollbackTargetCall<'a, C>
pub fn locations_delivery_pipelines_rollback_target( &self, request: RollbackTargetRequest, name: &str, ) -> ProjectLocationDeliveryPipelineRollbackTargetCall<'a, C>
Create a builder to help you perform the following task:
Creates a Rollout to roll back the specified target.
Arguments
request- No description provided.name- Required. TheDeliveryPipelinefor which the rollbackRolloutmust be created. The format isprojects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}.
Sourcepub fn locations_delivery_pipelines_set_iam_policy(
&self,
request: SetIamPolicyRequest,
resource: &str,
) -> ProjectLocationDeliveryPipelineSetIamPolicyCall<'a, C>
pub fn locations_delivery_pipelines_set_iam_policy( &self, request: SetIamPolicyRequest, resource: &str, ) -> ProjectLocationDeliveryPipelineSetIamPolicyCall<'a, C>
Create a builder to help you perform the following task:
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy is being specified. See Resource names for the appropriate value for this field.
Sourcepub fn locations_delivery_pipelines_test_iam_permissions(
&self,
request: TestIamPermissionsRequest,
resource: &str,
) -> ProjectLocationDeliveryPipelineTestIamPermissionCall<'a, C>
pub fn locations_delivery_pipelines_test_iam_permissions( &self, request: TestIamPermissionsRequest, resource: &str, ) -> ProjectLocationDeliveryPipelineTestIamPermissionCall<'a, C>
Create a builder to help you perform the following task:
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy detail is being requested. See Resource names for the appropriate value for this field.
Sourcepub fn locations_deploy_policies_create(
&self,
request: DeployPolicy,
parent: &str,
) -> ProjectLocationDeployPolicyCreateCall<'a, C>
pub fn locations_deploy_policies_create( &self, request: DeployPolicy, parent: &str, ) -> ProjectLocationDeployPolicyCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a new DeployPolicy in a given project and location.
Arguments
request- No description provided.parent- Required. The parent collection in which theDeployPolicymust be created. The format isprojects/{project_id}/locations/{location_name}.
Sourcepub fn locations_deploy_policies_delete(
&self,
name: &str,
) -> ProjectLocationDeployPolicyDeleteCall<'a, C>
pub fn locations_deploy_policies_delete( &self, name: &str, ) -> ProjectLocationDeployPolicyDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a single DeployPolicy.
Arguments
name- Required. The name of theDeployPolicyto delete. The format isprojects/{project_id}/locations/{location_name}/deployPolicies/{deploy_policy_name}.
Sourcepub fn locations_deploy_policies_get(
&self,
name: &str,
) -> ProjectLocationDeployPolicyGetCall<'a, C>
pub fn locations_deploy_policies_get( &self, name: &str, ) -> ProjectLocationDeployPolicyGetCall<'a, C>
Create a builder to help you perform the following task:
Gets details of a single DeployPolicy.
Arguments
name- Required. Name of theDeployPolicy. Format must beprojects/{project_id}/locations/{location_name}/deployPolicies/{deploy_policy_name}.
Sourcepub fn locations_deploy_policies_get_iam_policy(
&self,
resource: &str,
) -> ProjectLocationDeployPolicyGetIamPolicyCall<'a, C>
pub fn locations_deploy_policies_get_iam_policy( &self, resource: &str, ) -> ProjectLocationDeployPolicyGetIamPolicyCall<'a, C>
Create a builder to help you perform the following task:
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Arguments
resource- REQUIRED: The resource for which the policy is being requested. See Resource names for the appropriate value for this field.
Sourcepub fn locations_deploy_policies_list(
&self,
parent: &str,
) -> ProjectLocationDeployPolicyListCall<'a, C>
pub fn locations_deploy_policies_list( &self, parent: &str, ) -> ProjectLocationDeployPolicyListCall<'a, C>
Create a builder to help you perform the following task:
Lists DeployPolicies in a given project and location.
Arguments
parent- Required. The parent, which owns this collection of deploy policies. Format must beprojects/{project_id}/locations/{location_name}.
Sourcepub fn locations_deploy_policies_patch(
&self,
request: DeployPolicy,
name: &str,
) -> ProjectLocationDeployPolicyPatchCall<'a, C>
pub fn locations_deploy_policies_patch( &self, request: DeployPolicy, name: &str, ) -> ProjectLocationDeployPolicyPatchCall<'a, C>
Create a builder to help you perform the following task:
Updates the parameters of a single DeployPolicy.
Arguments
request- No description provided.name- Output only. Name of theDeployPolicy. Format isprojects/{project}/locations/{location}/deployPolicies/{deployPolicy}. ThedeployPolicycomponent must match[a-z]([a-z0-9-]{0,61}[a-z0-9])?
Sourcepub fn locations_deploy_policies_set_iam_policy(
&self,
request: SetIamPolicyRequest,
resource: &str,
) -> ProjectLocationDeployPolicySetIamPolicyCall<'a, C>
pub fn locations_deploy_policies_set_iam_policy( &self, request: SetIamPolicyRequest, resource: &str, ) -> ProjectLocationDeployPolicySetIamPolicyCall<'a, C>
Create a builder to help you perform the following task:
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy is being specified. See Resource names for the appropriate value for this field.
Sourcepub fn locations_operations_cancel(
&self,
request: CancelOperationRequest,
name: &str,
) -> ProjectLocationOperationCancelCall<'a, C>
pub fn locations_operations_cancel( &self, request: CancelOperationRequest, name: &str, ) -> ProjectLocationOperationCancelCall<'a, C>
Create a builder to help you perform the following task:
Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn’t support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.
Arguments
request- No description provided.name- The name of the operation resource to be cancelled.
Sourcepub fn locations_operations_delete(
&self,
name: &str,
) -> ProjectLocationOperationDeleteCall<'a, C>
pub fn locations_operations_delete( &self, name: &str, ) -> ProjectLocationOperationDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn’t support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Arguments
name- The name of the operation resource to be deleted.
Sourcepub fn locations_operations_get(
&self,
name: &str,
) -> ProjectLocationOperationGetCall<'a, C>
pub fn locations_operations_get( &self, name: &str, ) -> ProjectLocationOperationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
Arguments
name- The name of the operation resource.
Sourcepub fn locations_operations_list(
&self,
name: &str,
) -> ProjectLocationOperationListCall<'a, C>
pub fn locations_operations_list( &self, name: &str, ) -> ProjectLocationOperationListCall<'a, C>
Create a builder to help you perform the following task:
Lists operations that match the specified filter in the request. If the server doesn’t support this method, it returns UNIMPLEMENTED.
Arguments
name- The name of the operation’s parent resource.
Sourcepub fn locations_targets_create(
&self,
request: Target,
parent: &str,
) -> ProjectLocationTargetCreateCall<'a, C>
pub fn locations_targets_create( &self, request: Target, parent: &str, ) -> ProjectLocationTargetCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a new Target in a given project and location.
Arguments
request- No description provided.parent- Required. The parent collection in which theTargetmust be created. The format isprojects/{project_id}/locations/{location_name}.
Sourcepub fn locations_targets_delete(
&self,
name: &str,
) -> ProjectLocationTargetDeleteCall<'a, C>
pub fn locations_targets_delete( &self, name: &str, ) -> ProjectLocationTargetDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a single Target.
Arguments
name- Required. The name of theTargetto delete. The format isprojects/{project_id}/locations/{location_name}/targets/{target_name}.
Sourcepub fn locations_targets_get(
&self,
name: &str,
) -> ProjectLocationTargetGetCall<'a, C>
pub fn locations_targets_get( &self, name: &str, ) -> ProjectLocationTargetGetCall<'a, C>
Create a builder to help you perform the following task:
Gets details of a single Target.
Arguments
name- Required. Name of theTarget. Format must beprojects/{project_id}/locations/{location_name}/targets/{target_name}.
Sourcepub fn locations_targets_get_iam_policy(
&self,
resource: &str,
) -> ProjectLocationTargetGetIamPolicyCall<'a, C>
pub fn locations_targets_get_iam_policy( &self, resource: &str, ) -> ProjectLocationTargetGetIamPolicyCall<'a, C>
Create a builder to help you perform the following task:
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Arguments
resource- REQUIRED: The resource for which the policy is being requested. See Resource names for the appropriate value for this field.
Sourcepub fn locations_targets_list(
&self,
parent: &str,
) -> ProjectLocationTargetListCall<'a, C>
pub fn locations_targets_list( &self, parent: &str, ) -> ProjectLocationTargetListCall<'a, C>
Create a builder to help you perform the following task:
Lists Targets in a given project and location.
Arguments
parent- Required. The parent, which owns this collection of targets. Format must beprojects/{project_id}/locations/{location_name}.
Sourcepub fn locations_targets_patch(
&self,
request: Target,
name: &str,
) -> ProjectLocationTargetPatchCall<'a, C>
pub fn locations_targets_patch( &self, request: Target, name: &str, ) -> ProjectLocationTargetPatchCall<'a, C>
Create a builder to help you perform the following task:
Updates the parameters of a single Target.
Arguments
request- No description provided.name- Identifier. Name of theTarget. Format isprojects/{project}/locations/{location}/targets/{target}. Thetargetcomponent must match[a-z]([a-z0-9-]{0,61}[a-z0-9])?
Sourcepub fn locations_targets_set_iam_policy(
&self,
request: SetIamPolicyRequest,
resource: &str,
) -> ProjectLocationTargetSetIamPolicyCall<'a, C>
pub fn locations_targets_set_iam_policy( &self, request: SetIamPolicyRequest, resource: &str, ) -> ProjectLocationTargetSetIamPolicyCall<'a, C>
Create a builder to help you perform the following task:
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy is being specified. See Resource names for the appropriate value for this field.
Sourcepub fn locations_targets_test_iam_permissions(
&self,
request: TestIamPermissionsRequest,
resource: &str,
) -> ProjectLocationTargetTestIamPermissionCall<'a, C>
pub fn locations_targets_test_iam_permissions( &self, request: TestIamPermissionsRequest, resource: &str, ) -> ProjectLocationTargetTestIamPermissionCall<'a, C>
Create a builder to help you perform the following task:
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy detail is being requested. See Resource names for the appropriate value for this field.
Sourcepub fn locations_get(&self, name: &str) -> ProjectLocationGetCall<'a, C>
pub fn locations_get(&self, name: &str) -> ProjectLocationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets information about a location.
Arguments
name- Resource name for the location.
Sourcepub fn locations_get_config(
&self,
name: &str,
) -> ProjectLocationGetConfigCall<'a, C>
pub fn locations_get_config( &self, name: &str, ) -> ProjectLocationGetConfigCall<'a, C>
Create a builder to help you perform the following task:
Gets the configuration for a location.
Arguments
name- Required. Name of requested configuration.
Sourcepub fn locations_list(&self, name: &str) -> ProjectLocationListCall<'a, C>
pub fn locations_list(&self, name: &str) -> ProjectLocationListCall<'a, C>
Create a builder to help you perform the following task:
Lists information about the supported locations for this service.
Arguments
name- The resource that owns the locations collection, if applicable.