pub struct Retry {
pub attempts: Option<i64>,
pub backoff_mode: Option<String>,
pub wait: Option<Duration>,
}Expand description
Retries the failed job.
This type is not used in any activity, and only used as part of another schema.
Fields
attempts: Option<i64>Required. Total number of retries. Retry is skipped if set to 0; The minimum value is 1, and the maximum value is 10.
backoff_mode: Option<String>Optional. The pattern of how wait time will be increased. Default is linear. Backoff mode will be ignored if wait is 0.
wait: Option<Duration>Optional. How long to wait for the first retry. Default is 0, and the maximum value is 14d.