pub struct Rollback {
pub destination_phase: Option<String>,
pub disable_rollback_if_rollout_pending: Option<bool>,
}Expand description
Rolls back a Rollout.
This type is not used in any activity, and only used as part of another schema.
Fields
destination_phase: Option<String>Optional. The starting phase ID for the Rollout. If unspecified, the Rollout will start in the stable phase.
disable_rollback_if_rollout_pending: Option<bool>Optional. If pending rollout exists on the target, the rollback operation will be aborted.