pub struct RollbackTargetRequest {
pub override_deploy_policy: Option<Vec<String>>,
pub release_id: Option<String>,
pub rollback_config: Option<RollbackTargetConfig>,
pub rollout_id: Option<String>,
pub rollout_to_roll_back: Option<String>,
pub target_id: Option<String>,
pub validate_only: Option<bool>,
}Expand description
The request object for RollbackTarget.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
override_deploy_policy: Option<Vec<String>>Optional. Deploy policies to override. Format is projects/{project}/locations/{location}/deployPolicies/{deploy_policy}.
release_id: Option<String>Optional. ID of the Release to roll back to. If this isn’t specified, the previous successful Rollout to the specified target will be used to determine the Release.
rollback_config: Option<RollbackTargetConfig>Optional. Configs for the rollback Rollout.
rollout_id: Option<String>Required. ID of the rollback Rollout to create.
rollout_to_roll_back: Option<String>Optional. If provided, this must be the latest Rollout that is on the Target.
target_id: Option<String>Required. ID of the Target that is being rolled back.
validate_only: Option<bool>Optional. If set to true, the request is validated and the user is provided with a RollbackTargetResponse.