pub struct RolloutRestriction {
pub actions: Option<Vec<String>>,
pub id: Option<String>,
pub invokers: Option<Vec<String>>,
pub time_windows: Option<TimeWindows>,
}Expand description
Rollout restrictions.
This type is not used in any activity, and only used as part of another schema.
Fields
actions: Option<Vec<String>>Optional. Rollout actions to be restricted as part of the policy. If left empty, all actions will be restricted.
id: Option<String>Required. Restriction rule ID. Required and must be unique within a DeployPolicy. The format is [a-z]([a-z0-9-]{0,61}[a-z0-9])?.
invokers: Option<Vec<String>>Optional. What invoked the action. If left empty, all invoker types will be restricted.
time_windows: Option<TimeWindows>Required. Time window within which actions are restricted.