pub struct RouteDestinations {
pub destination_ids: Option<Vec<String>>,
pub propagate_service: Option<bool>,
}Expand description
Information about route destinations for the Gateway API service mesh.
This type is not used in any activity, and only used as part of another schema.
Fields
destination_ids: Option<Vec<String>>Required. The clusters where the Gateway API HTTPRoute resource will be deployed to. Valid entries include the associated entities IDs configured in the Target resource and “@self” to include the Target cluster.
propagate_service: Option<bool>Optional. Whether to propagate the Kubernetes Service to the route destination clusters. The Service will always be deployed to the Target cluster even if the HTTPRoute is not. This option may be used to facilitate successful DNS lookup in the route destination clusters. Can only be set to true if destinations are specified.