pub struct TimeWindows {
pub one_time_windows: Option<Vec<OneTimeWindow>>,
pub time_zone: Option<String>,
pub weekly_windows: Option<Vec<WeeklyWindow>>,
}Expand description
Time windows within which actions are restricted. See the documentation for more information on how to configure dates/times.
This type is not used in any activity, and only used as part of another schema.
Fields
one_time_windows: Option<Vec<OneTimeWindow>>Optional. One-time windows within which actions are restricted.
time_zone: Option<String>Required. The time zone in IANA format IANA Time Zone Database (e.g. America/New_York).
weekly_windows: Option<Vec<WeeklyWindow>>Optional. Recurring weekly windows within which actions are restricted.