pub struct TimedPromoteReleaseCondition {
pub next_promotion_time: Option<DateTime<Utc>>,
pub targets_list: Option<Vec<Targets>>,
}Expand description
TimedPromoteReleaseCondition contains conditions specific to an Automation with a Timed Promote Release rule defined.
This type is not used in any activity, and only used as part of another schema.
Fields
next_promotion_time: Option<DateTime<Utc>>Output only. When the next scheduled promotion(s) will occur.
targets_list: Option<Vec<Targets>>Output only. A list of targets involved in the upcoming timed promotion(s).