pub struct TimedPromoteReleaseOperation {
pub phase: Option<String>,
pub release: Option<String>,
pub target_id: Option<String>,
}Expand description
Contains the information of an automated timed promote-release operation.
This type is not used in any activity, and only used as part of another schema.
Fields
phase: Option<String>Output only. The starting phase of the rollout created by this operation.
release: Option<String>Output only. The name of the release to be promoted.
target_id: Option<String>Output only. The ID of the target that represents the promotion stage to which the release will be promoted. The value of this field is the last segment of a target name.