pub struct ToolVersionSupportedCondition {
pub maintenance_mode_time: Option<DateTime<Utc>>,
pub status: Option<bool>,
pub support_expiration_time: Option<DateTime<Utc>>,
pub tool_version_support_state: Option<String>,
}Expand description
ToolVersionSupportedCondition contains information about when support for the release’s version of a Tool ends.
This type is not used in any activity, and only used as part of another schema.
Fields
maintenance_mode_time: Option<DateTime<Utc>>Output only. The time at which this release’s version of the Tool will enter maintenance mode.
status: Option<bool>Output only. True if the version of Tool used by this release is supported.
support_expiration_time: Option<DateTime<Utc>>Output only. The time at which this release’s version of the Tool will no longer be supported.
tool_version_support_state: Option<String>Output only. The Tool support state for this release’s version of the Tool.