pub struct ToolVersions {
pub docker: Option<String>,
pub helm: Option<String>,
pub kpt: Option<String>,
pub kubectl: Option<String>,
pub kustomize: Option<String>,
pub skaffold: Option<String>,
}Expand description
Details of ToolVersions for the release.
This type is not used in any activity, and only used as part of another schema.
Fields
docker: Option<String>Optional. The docker version to use for Cloud Deploy operations.
helm: Option<String>Optional. The helm version to use for Cloud Deploy operations.
kpt: Option<String>Optional. The kpt version to use for Cloud Deploy operations.
kubectl: Option<String>Optional. The kubectl version to use for Cloud Deploy operations.
kustomize: Option<String>Optional. The kustomize version to use for Cloud Deploy operations.
skaffold: Option<String>Optional. The skaffold version to use for Cloud Deploy operations.