WeeklyWindow

Struct WeeklyWindow 

pub struct WeeklyWindow {
    pub days_of_week: Option<Vec<String>>,
    pub end_time: Option<TimeOfDay>,
    pub start_time: Option<TimeOfDay>,
}
Weekly windows. For example, blocking actions every Saturday and Sunday. Another example would be blocking actions every weekday from 5pm to midnight.

This type is not used in any activity, and only used as part of another schema.

Fields

days_of_week: Option<Vec<String>>

Optional. Days of week. If left empty, all days of the week will be included.

end_time: Option<TimeOfDay>

Optional. End time (exclusive). Use 24:00 to indicate midnight. If you specify end_time you must also specify start_time. If left empty, this will block for the entire day for the days specified in days_of_week.

start_time: Option<TimeOfDay>

Optional. Start time (inclusive). Use 00:00 for the beginning of the day. If you specify start_time you must also specify end_time. If left empty, this will block for the entire day for the days specified in days_of_week.