pub struct TimedPromoteReleaseRule {
pub condition: Option<AutomationRuleCondition>,
pub destination_phase: Option<String>,
pub destination_target_id: Option<String>,
pub id: Option<String>,
pub schedule: Option<String>,
pub time_zone: Option<String>,
}Expand description
The TimedPromoteReleaseRule will automatically promote a release from the current target(s) to the specified target(s) on a configured schedule.
This type is not used in any activity, and only used as part of another schema.
Fields
condition: Option<AutomationRuleCondition>Output only. Information around the state of the Automation rule.
destination_phase: Option<String>Optional. The starting phase of the rollout created by this rule. Default to the first phase.
destination_target_id: Option<String>Optional. The ID of the stage in the pipeline to which this Release is deploying. If unspecified, default it to the next stage in the promotion flow. The value of this field could be one of the following: * The last segment of a target name * “@next”, the next target in the promotion sequence
id: Option<String>Required. ID of the rule. This ID must be unique in the Automation resource to which this rule belongs. The format is [a-z]([a-z0-9-]{0,61}[a-z0-9])?.
schedule: Option<String>Required. Schedule in crontab format. e.g. “0 9 * * 1” for every Monday at 9am.
time_zone: Option<String>Required. The time zone in IANA format IANA Time Zone Database (e.g. America/New_York).